@@ -255,7 +255,7 @@ import           System.Console.Chalk
                  , yellow )
 
 import           Text.Strung as S
-                 ( IsStrung
+                 ( IsStrung (toString)
                  , fromString
                  , intercalate )
 
@@ -365,9 +365,9 @@ checkCompletionError' dump' errorSpec' = maybeMVoid check' where
 completionError :: IsStrung a => OptsError -> a -> ExitCode -> IO ()
 completionError = c' where
     c' OptsIgnoreErr _ _  = pure ()
-    c' OptsWarn str code  = warn str
-    c' OptsThrow str code = throw $ CompletionException code str
-    c' OptsDie str code   = dieWithCode code str
+    c' OptsWarn str code  = warn (toString str)
+    c' OptsThrow str code = throw $ CompletionException code (toString str)
+    c' OptsDie str code   = dieWithCode code (toString str)
 
 spawnError :: (SpawnRecover a, Exception e) => Bool -> Bool -> Bool -> e -> IO a
 spawnError throw' die' warn' = f where
@@ -531,11 +531,11 @@ create (Proc f a) cwdMb = (proc f a) { delegate_ctlc = False
 tryCreateProcess :: String -> CreateProcess -> IO (Either SomeException CreateProcessRet')
 tryCreateProcess = try .: createProcess_
 
-printCmd' :: IsStrung a => Maybe FilePath -> CmdRun -> (Bool, Bool, Bool) -> a
+printCmd' :: Maybe String -> CmdRun -> (Bool, Bool, Bool) -> String
 printCmd' cwdMb cmdRun handles = joinNL . concat $ print' where
     print' = [ printCwd' cwdMb, [ printCmd'' cmdRun handles ] ]
     printCwd' Nothing = []
-    printCwd' (Just fp) = [infoStr . S.fromString $ "[ " <> yellow "chdir" <> " ] " <> fp]
+    printCwd' (Just fp) = [infoStr . toString $ "[ " <> yellow "chdir" <> " ] " <> fp]
     printCmd'' (Shell s) = fmt id s []
     printCmd'' (Proc f a) = fmt cyan f a
     fmt color' h t = fmt' (head' color' h) (tail' t)
