@@ -15,15 +15,14 @@ import           System.Posix.Process
 import           Text.Speak.IO
                  ( err )
 
-import           Text.Strung
-                 ( IsStrung )
+import           Text.Strung ( IsStrung (toString) )
 
 die :: IsStrung a => a -> IO b
 die = dieWithCode $ ExitFailure 1
 
 dieWithCode :: IsStrung a => ExitCode -> a -> IO b
 dieWithCode code e = failAfter f where
-    f = err e >> closeStdio >> exitImmediately code
+    f = err (toString e) >> closeStdio >> exitImmediately code
 
 closeStdio = mapM_ hClose [stdin, stdout, stderr]
 
